package org.garret.xmlme;

/**
 * Exception thrown by XML parser
 */
public class XMLException extends RuntimeException { 
    /**
     * Constructor of exception with position in XML buffer
     * @param line line number
     * @param column column
     */
    public XMLException(int line, int column, String message) { 
        super("In line " + line + " column " + column + ": " + message);
        this.line = line;
        this.column = column;
        this.message = message;
    }

    /**
     * Constructor of exception without position
     */
    public XMLException(String message) { 
        super(message);
        this.message = message;
    }

    /**
     * Get message text
     * @return reason of exception
     */
    public String getMessageText() { 
        return message;
    }
    
    /**
     * Line number where exception happen
     * @return line number
     */
    public int getLine() { 
        return line;
    }

    /**
     * Column where exception happen
     * @return column number
     */
    public int getColumn() { 
        return column;
    }

    private int line;
    private int column;
    private String message;
}
